%define major 8
%define intllibname %mklibname intl %{major}
%define misclibname %mklibname gettextmisc

%define do_check 1
%{?_without_check: %global do_check 0}

%define enable_java 0
%{?_without_java: %global enable_java 0}

%define enable_csharp 0
%{?_with_csharp: %global enable_csharp 1}

Name:		gettext
Summary:	GNU libraries and utilities for producing multi-lingual messages
Version:	0.18.1.1
Release:	%mkrel 2
License:	GPL
Group:		System/Internationalization
URL:		http://www.gnu.org/software/gettext/
Source:		ftp://ftp.gnu.org/pub/gnu/%{name}/%{name}-%{version}.tar.gz
Source1:	%{SOURCE0}.sig
Source2:	po-mode-init.el
Patch8:		gettext-0.18.1-fix-str-fmt.patch
Patch9:		gettext-0.18.1.1-linkage.patch
# (Abel) we pick mono here, though pnet can be used as well.
%if %enable_csharp
BuildRequires:	mono
%endif
%if %enable_java
BuildRequires:	eclipse-ecj
BuildRequires:	gcc-java
BuildRequires:	gcj-tools
BuildRequires:	fastjar
%endif
BuildRequires:  automake
BuildRequires:	bison
BuildRequires:	flex
BuildRequires:	emacs-bin
BuildRequires:	texinfo
BuildRequires:	libgomp-devel
BuildRequires:	libcroco0.6-devel
BuildRequires:	libunistring-devel
BuildRequires:	ncurses-devel
BuildRequires:	libxml2-devel
BuildRequires:	acl-devel
# test suite
BuildRequires:	locales-fa
BuildRequires:	locales-fr
BuildRequires:	locales-ja
BuildRequires:	locales-zh

Requires:	%{name}-base = %{version}
Requires:	%{misclibname} = %{version}
# xgettext will dlopen() it when extracting strings from glade files
Requires:	%mklibname expat 1
Requires(post):	info-install
Requires(preun): info-install
BuildRoot:	%{_tmppath}/%{name}-%{version}-%{release}-buildroot

%description
The GNU gettext package provides a set of tools and documentation for producing
multi-lingual messages in programs. Tools include a set of conventions about
how programs should be written to support message catalogs, a directory and
file naming organization for the message catalogs, a runtime library which
supports the retrieval of translated messages, and stand-alone programs for
handling the translatable and the already translated strings. Gettext provides
an easy to use library and tools for creating, using, and modifying natural
language catalogs and is a powerful and simple method for internationalizing
programs.

If you would like to internationalize or incorporate multi-lingual messages
into programs that you're developing, you should install gettext.

Build Option:
--with csharp          Enables C# support in gettext
--without java         Disables Java support in gettext

%package	-n %{intllibname}
Summary:	Basic libintl library for internationalization
Group:		System/Libraries
License:	LGPL
Provides:	libintl = %{version}-%{release}

%description	-n %{intllibname}
This package contains the libintl library, which is important for
system internationalization.

%package	-n %{misclibname}
Summary:	Other %{name} libraries needed by %{name} utilities
Group:		System/Libraries
License:	LGPL
Provides:       libgettextmisc

%description	-n %{misclibname}
This package contains all other libraries used by %{name} utilities,
and are not very widely used outside %{name}.

%package	devel
Summary:	Development files for %{name}
Group:		Development/C
License:	LGPL
Requires:	%{name} = %{version}
# fwang: autopoint requires cvs to work
Requires:	cvs
Requires(post): info-install
Requires(preun): info-install

%description	devel
This package contains all development related files necessary for
developing or compiling applications/libraries that needs
internationalization capability. You also need this package if you
want to add gettext support for your project.

%package	base
Summary:	Basic binary for showing translation of textual messages
Group:		System/Internationalization
Requires:	%{intllibname} = %{version}
Conflicts: gettext < 0.14.5-3mdk

%description	base
This package contains the basic binary from %{name}. It is splitted from
%{name} because initscript need it to show translated boot messages.

%if %enable_java
%package	java
Summary:	Java binding for GNU gettext
Group:		System/Internationalization
Requires:	%{name} = %{version}

%description	java
This package contains class file that implements the main GNU libintl
functions in Java. This allows compiling GNU gettext message catalogs
into Java ResourceBundle classes.
%endif

%if %enable_csharp
%package	csharp
Summary:	C# binding for GNU gettext
Group:		System/Internationalization
Requires:	mono

%description	csharp
This package contains class file that implements the main GNU libintl
functions in C#. This allows compiling GNU gettext message catalogs
into C# dll or resource files.
%endif

%prep
%setup -q
%patch8 -p0 -b .str
%patch9 -p1 -b .link

%build

%if %enable_java
export GCJ="%{_bindir}/gcj"
export JAVAC="%{_bindir}/gcj -C"
export JAR="%{_bindir}/fastjar"
%endif

autoreconf -fi
for i in `find -name configure|sort`
do
pushd `dirname $i`
%configure2_5x \
	--enable-shared \
	--with-included-gettext \
%if %enable_csharp
	--enable-csharp=mono \
%else
	--disable-csharp \
%endif
%if ! %enable_java
	--disable-java \
%endif

popd
done

%make

%if %do_check
%check
export JAVAC=ecj
LC_ALL=C make check
%endif

%install
rm -rf $RPM_BUILD_ROOT
%makeinstall_std

# remove unwanted files
rm -f $RPM_BUILD_ROOT%{_includedir}/libintl.h \
      $RPM_BUILD_ROOT%{_datadir}/locale/locale.alias
rm -f gettext-runtime/intl-java/javadoc2/package-list

install -D -m 644 %{SOURCE2} $RPM_BUILD_ROOT%{_sysconfdir}/emacs/site-start.d/%{name}.el

# remove non-standard lc directories
for i in en@boldquot en@quot ; do rm -rf $RPM_BUILD_ROOT/%{_datadir}/locale/$i; done

# move installed doc back to %%doc
rm -rf htmldoc examples
mkdir htmldoc
for i in gettext-runtime/man/*.html; do
  rm -f $RPM_BUILD_ROOT%{_datadir}/doc/gettext/`basename $i`
done
rm -rf $RPM_BUILD_ROOT%{_datadir}/doc/gettext/javadoc*
mv $RPM_BUILD_ROOT%{_datadir}/doc/gettext/* $RPM_BUILD_ROOT/%{_datadir}/doc/libasprintf/* htmldoc
mv htmldoc/examples examples

# move crucial stuff to /lib and /bin
pushd $RPM_BUILD_ROOT
mkdir -p bin
mkdir -p ./%{_lib}
mv usr/bin/gettext bin/
ln -s ../../bin/gettext usr/bin/gettext
mv .%{_libdir}/libintl.so.* ./%{_lib}/
rm -f .%{_libdir}/libintl.so
# if major changed, then package build will fail, which is a GOOD THING.
# this prevents mindless packaging.
[ -f %{_lib}/libintl.so.%{major} ] && \
  ln -s ../../%{_lib}/libintl.so.%{major} .%{_libdir}/libintl.so
popd

# remove java stuff, otherwise rpm complains
%if !%enable_java
rm -f $RPM_BUILD_ROOT%{_libdir}/%{name}/gnu.gettext.* \
      $RPM_BUILD_ROOT%{_datadir}/%{name}/*.jar
%endif

%find_lang %{name} --all-name

%clean
rm -rf $RPM_BUILD_ROOT

%post
%_install_info %{name}.info

%preun
%_remove_install_info %{name}.info

%post devel
%_install_info autosprintf.info

%preun devel
%_remove_install_info autosprintf.info

%if %mdkversion < 200900
%post -n %{intllibname} -p /sbin/ldconfig
%endif
%if %mdkversion < 200900
%postun -n %{intllibname} -p /sbin/ldconfig
%endif

%if %mdkversion < 200900
%post -n %{misclibname} -p /sbin/ldconfig
%endif
%if %mdkversion < 200900
%postun -n %{misclibname} -p /sbin/ldconfig
%endif

%files
%defattr(-,root,root)
%doc AUTHORS README COPYING gettext-runtime/ABOUT-NLS gettext-runtime/BUGS NEWS THANKS 
%config(noreplace) %{_sysconfdir}/emacs/site-start.d/*.el
%{_bindir}/envsubst
%{_bindir}/gettext.sh
%{_bindir}/msg*
%{_bindir}/recode-sr-latin
%{_bindir}/xgettext
%dir %{_datadir}/gettext
%{_datadir}/%{name}/msgunfmt.tcl
%{_datadir}/%{name}/projects
%{_datadir}/%{name}/javaversion.class
%{_datadir}/%{name}/styles
%dir %{_libdir}/%{name}
%{_libdir}/%{name}/hostname
%{_libdir}/%{name}/project-id
%{_libdir}/%{name}/urlget
%{_libdir}/%{name}/user-email
%if %enable_java
%exclude %{_libdir}/%{name}/gnu.gettext.*
%endif
%{_infodir}/gettext.*
%{_datadir}/emacs/site-lisp/*.el*
%{_mandir}/man1/envsubst.*
%{_mandir}/man1/msg*
%{_mandir}/man1/xgettext.*
%{_mandir}/man1/recode-sr-latin.*

%files base -f %{name}.lang
%defattr(-,root,root)
%doc gettext-runtime/man/*.1.html
/bin/gettext
%{_bindir}/gettext
%{_bindir}/ngettext
%{_mandir}/man1/gettext*
%{_mandir}/man1/ngettext*

%files -n %{intllibname}
%defattr(-,root,root)
%doc gettext-runtime/intl/COPYING*
/%{_lib}/lib*.so.*

%files -n %{misclibname}
%defattr(-,root,root)
%doc gettext-runtime/intl/COPYING*
%{_libdir}/lib*-*.*.so
%{_libdir}/lib*.so.*

%files devel
%defattr(-,root,root)
%doc gettext-runtime/man/*.3.html examples htmldoc
%{_bindir}/autopoint
%{_bindir}/gettextize
%{_datadir}/%{name}/ABOUT-NLS
%{_datadir}/%{name}/archive*
%{_datadir}/%{name}/config.rpath
%{_datadir}/%{name}/*.h
%{_datadir}/%{name}/intl
%{_datadir}/%{name}/po
%{_datadir}/aclocal/*
%{_includedir}/*
%{_infodir}/autosprintf*
%{_libdir}/lib*.a
%{_libdir}/lib*.la
# "lib*.so" cannot be used (it should be 'lib[^\.]*\.so' regexp in fact
# but using regexp is not possible here; so we list all files manually
%{_libdir}/libasprintf.so
%{_libdir}/libgettextlib.so
%{_libdir}/libgettextpo.so
%{_libdir}/libgettextsrc.so
%{_libdir}/libintl.so
%{_mandir}/man1/autopoint.*
%{_mandir}/man3/*

%if %enable_java
%files java
%defattr(-,root,root)
%doc gettext-runtime/intl-java/javadoc*
%{_libdir}/%{name}/gnu.gettext.*
%{_datadir}/%{name}/*.jar
%endif

%if %enable_csharp
%files csharp
%defattr(-,root,root)
%doc gettext-runtime/intl-csharp/csharpdoc/*
%{_libdir}/*.dll
%{_libdir}/gettext/*.exe
%endif


%changelog
* Tue May 03 2011 Oden Eriksson <oeriksson@mandriva.com> 0.18.1.1-2mdv2011.0
+ Revision: 664824
- mass rebuild

* Fri Jul 09 2010 Funda Wang <fwang@mandriva.org> 0.18.1.1-1mdv2011.0
+ Revision: 549878
- New version 0.18.1.1

* Thu Apr 29 2010 Christophe Fergeau <cfergeau@mandriva.com> 0.17-9mdv2010.1
+ Revision: 540832
- rebuild so that shared libraries are properly stripped again

* Wed Apr 28 2010 Christophe Fergeau <cfergeau@mandriva.com> 0.17-8mdv2010.1
+ Revision: 540340
- rebuild so that shared libraries are properly stripped again

* Wed Apr 28 2010 Christophe Fergeau <cfergeau@mandriva.com> 0.17-7mdv2010.1
+ Revision: 540026
- rebuild so that shared libraries are properly stripped again

* Sun Mar 14 2010 Oden Eriksson <oeriksson@mandriva.com> 0.17-6mdv2010.1
+ Revision: 519004
- rebuild

* Wed Sep 02 2009 Christophe Fergeau <cfergeau@mandriva.com> 0.17-5mdv2010.0
+ Revision: 424835
- rebuild

* Sat Dec 20 2008 Oden Eriksson <oeriksson@mandriva.com> 0.17-4mdv2009.1
+ Revision: 316753
- added some more -Werror=format-security fixes
- fix build with -Werror=format-security (P8)
- added some required conditional spec file voodoo magic

* Sun Jun 29 2008 Oden Eriksson <oeriksson@mandriva.com> 0.17-3mdv2009.0
+ Revision: 229927
- added P7 from fedora to make it build with glibc28

  + Thierry Vignaud <tv@mandriva.org>
    - rebuild
    - kill re-definition of %%buildroot on Pixel's request
    - move HTML doc in devel sub package

  + Pixel <pixel@mandriva.com>
    - do not call ldconfig in %%post/%%postun, it is now handled by filetriggers

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

* Sat Nov 10 2007 Funda Wang <fwang@mandriva.org> 0.17-1mdv2008.1
+ Revision: 107431
- fix file list
- drop old gettext-tools fr translation.
- New version 0.17

* Wed Sep 26 2007 Funda Wang <fwang@mandriva.org> 0.16.1-4mdv2008.0
+ Revision: 93043
- fix building by adding BR

* Thu Jun 07 2007 Tomasz Pawel Gajc <tpg@mandriva.org> 0.16.1-3mdv2008.0
+ Revision: 36885
- rebuild for expat

* Sun May 27 2007 Funda Wang <fwang@mandriva.org> 0.16.1-2mdv2008.0
+ Revision: 31725
- gettext-devel (autopoint) requires cvs to work


* Thu Feb 08 2007 Thierry Vignaud <tvignaud@mandriva.com> 0.16.1-1mdv2007.0
+ Revision: 118110
- update sig
- new release

  + Gwenole Beauchesne <gbeauchesne@mandriva.com>

* Fri Jan 12 2007 Nicolas Lécureuil <neoclust@mandriva.org> 0.16-3mdv2007.1
+ Revision: 107741
- Build w/o java support
- Fix file list when builded w/o java
- Fix Provides

  + Thierry Vignaud <tvignaud@mandriva.com>
    - fix build
    - simplif doble buildrequire
    - fix buildrequires for test suite
    - parallel build is currently broken
    - update file list for 0.16
    - new release
    - major was bumped
    - new release

* Tue Oct 31 2006 Oden Eriksson <oeriksson@mandriva.com> 0.14.6-5mdv2007.1
+ Revision: 74673
- rebuild
- bzip2 cleanup
- fix build for the java stuff
- rebuild
- bunzip patches
- Import gettext

* Thu Jun 29 2006 Thierry Vignaud <tvignaud@mandriva.com> 0.14.6-1mdv2007.0
- new release
- rediff patch 2
- fix running test suite in a l10n environment
- move autopoint in the devel sub package (#22553)
- patch 6: workaround broken testsuite

* Sat Aug 13 2005 Gwenole Beauchesne <gbeauchesne@mandriva.com> 0.14.5-2mdk
- build --disabled-shared autoconf-lib-link tests --with-pic

* Mon Jul 04 2005 Abel Cheung <deaddog@mandriva.org> 0.14.5-1mdk
- New release

* Sun Apr 17 2005 Abel Cheung <deaddog@mandriva.org> 0.14.4-1mdk
- New version
- Not applying libtool x86_64 patch for now, looks like bundled libtool
  (1.5.14) has x86_64 support
- Rediff patch5
- Remove patch6 (similar fix upstream), patch7 (upstream)
- S3: Use alternative french translation (#14341)

* Fri Nov 26 2004 Abel Cheung <deaddog@mandrake.org> 0.14.1-10mdk
- P6: fix CAN-2004-0966 (scripts allow symlink attack on temp files)
- P7: assorted CVS fixes
- Split C# stuff into another package if people really compile RPM with C# support

* Tue Sep 21 2004 Christiaan Welvaart <cjw@daneel.dyndns.org> 0.14.1-9mdk
- fix buildrequires (automake1.7 -> automake1.8)

* Wed Jul 28 2004 Gwenole Beauchesne <gbeauchesne@mandrakesoft.com> 0.14.1-8mdk
- merge from amd64-branch: fix broken built-in libtool

* Fri Jun 04 2004 Gwenole Beauchesne <gbeauchesne@mandrakesoft.com> 0.14.1-7mdk
- rebuild against gcc3.4

* Tue Jun 01 2004 Götz Waschk <waschk@linux-mandrake.com> 0.14.1-6mdk
- fix emacs site-start file

* Sun May 23 2004 Abel Cheung <deaddog@deaddog.org> 0.14.1-5mdk
- Drop patch0 (libtool) and patch1 (newer javac don't output error when
  copying class file onto itself anymore)
- Can optionally build C# support (using mono)

* Sat Apr 24 2004 Thierry Vignaud <tvignaud@mandrakesoft.com> 0.14.1-4mdk
- fix %%_libdir/libintl.so link

* Thu Apr 22 2004 Götz Waschk <waschk@linux-mandrake.com> 0.14.1-3mdk
- fix emacs site-start script

* Tue Apr 20 2004 Per Øyvind Karlsen <peroyvind@linux-mandrake.com> 0.14.1-2mdk
- fix provides (from Charles A Edwards <eslrahc@bellsouth.net>)

* Mon Apr 19 2004 Per Øyvind Karlsen <peroyvind@linux-mandrake.com> 0.14.1-1mdk
- 0.14.1
- bump major to 3
- nuke unpackaged files

